# -*- mode: python -*-
# vi: set ft=python :

"""
Makes Boost headers available to be used as a C/C++ dependency.

Example:
    WORKSPACE:
        load("@drake//tools/workspace/boost:repository.bzl", "boost_repository")  # noqa
        boost_repository(name = "foo")

    BUILD:
        cc_library(
            name = "foobar",
            deps = ["@foo//:boost_headers"],
            srcs = ["bar.cc"],
        )

Argument:
    name: A unique name for this rule.
"""

HDRS_PATTERNS = [
    "boost/**/*.h",
    "boost/**/*.hpp",
    "boost/**/*.ipp",
]

LINUX_PREFIX = "/usr"

MAC_OS_X_PREFIX = "/usr/local/opt/boost"

def _impl(repository_ctx):
    if repository_ctx.os.name == "mac os x":
        prefix = MAC_OS_X_PREFIX
    elif repository_ctx.os.name == "linux":
        prefix = LINUX_PREFIX
    else:
        fail(
            "Operating system is NOT supported",
            attr = repository_ctx.os.name,
        )

    repository_ctx.symlink("{}/include/boost".format(prefix), "boost")

    file_content = """# -*- python -*-

# DO NOT EDIT: generated by boost_repository()

licenses(["notice"])  # BSL-1.0

cc_library(
    name = "boost_headers",
    hdrs = glob({}),
    includes = ["."],
    visibility = ["//visibility:public"],
)
    """.format(HDRS_PATTERNS)

    repository_ctx.file(
        "BUILD.bazel",
        content = file_content,
        executable = False,
    )

boost_repository = repository_rule(
    local = True,
    implementation = _impl,
)
